@@ -37,7 +37,7 @@ describe("cli", () => {
         error: sinon.spy()
     };
     const cli = proxyquire("../../lib/cli", {
-        "./logging": log
+        "./util/logging": log
     });
 
     /**
@@ -58,7 +58,7 @@ describe("cli", () => {
 
         const localCLI = proxyquire("../../lib/cli", {
             "./cli-engine": fakeCLIEngine,
-            "./logging": log
+            "./util/logging": log
         });
 
         localCLI.execute(cmd);
@@ -267,6 +267,17 @@ describe("cli", () => {
         });
     });
 
+    describe("when using --fix-type without --fix or --fix-dry-run", () => {
+        it("should exit with error", () => {
+            const filePath = getFixturePath("passing.js");
+            const code = `--fix-type suggestion ${filePath}`;
+
+            const exit = cli.execute(code);
+
+            assert.strictEqual(exit, 2);
+        });
+    });
+
     describe("when executing a file with a syntax error", () => {
         it("should exit with error", () => {
             const filePath = getFixturePath("syntax-error.js");
@@ -391,7 +402,7 @@ describe("cli", () => {
                 const exit = cli.execute(code);
 
                 assert.strictEqual(exit, 2);
-            }, /Error while loading rule 'custom-rule': Cannot read property/);
+            }, /Error while loading rule 'custom-rule': Cannot read property/u);
         });
 
         it("should return a warning when rule is matched", () => {
@@ -697,7 +708,7 @@ describe("cli", () => {
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             localCLI.execute("--no-inline-config .");
@@ -715,11 +726,12 @@ describe("cli", () => {
                 results: []
             });
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.stub();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute(".");
@@ -751,11 +763,12 @@ describe("cli", () => {
                 results: []
             });
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.mock().once();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .");
@@ -764,6 +777,7 @@ describe("cli", () => {
 
         });
 
+
         it("should rewrite files when in fix mode", () => {
 
             const report = {
@@ -787,11 +801,12 @@ describe("cli", () => {
             fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
             sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.mock().withExactArgs(report);
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .");
@@ -823,12 +838,13 @@ describe("cli", () => {
             fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
             sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.getErrorResults = sandbox.stub().returns([]);
             fakeCLIEngine.outputFixes = sandbox.mock().withExactArgs(report);
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix --quiet .");
@@ -844,7 +860,7 @@ describe("cli", () => {
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix .", "foo = bar;");
@@ -874,11 +890,12 @@ describe("cli", () => {
                 results: []
             });
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .");
@@ -887,6 +904,36 @@ describe("cli", () => {
 
         });
 
+        it("should pass fixTypes to CLIEngine when --fix-type is passed", () => {
+
+            const expectedCLIEngineOptions = {
+                fix: true,
+                fixTypes: ["suggestion"]
+            };
+
+            // create a fake CLIEngine to test with
+            const fakeCLIEngine = sandbox.mock().withExactArgs(sinon.match(expectedCLIEngineOptions));
+
+            fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
+            sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns({
+                errorCount: 0,
+                warningCount: 0,
+                results: []
+            });
+            sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
+            fakeCLIEngine.outputFixes = sandbox.stub();
+
+            localCLI = proxyquire("../../lib/cli", {
+                "./cli-engine": fakeCLIEngine,
+                "./util/logging": log
+            });
+
+            const exitCode = localCLI.execute("--fix-dry-run --fix-type suggestion .");
+
+            assert.strictEqual(exitCode, 0);
+        });
+
         it("should not rewrite files when in fix-dry-run mode", () => {
 
             const report = {
@@ -910,11 +957,12 @@ describe("cli", () => {
             fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
             sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .");
@@ -946,12 +994,13 @@ describe("cli", () => {
             fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
             sandbox.stub(fakeCLIEngine.prototype, "executeOnFiles").returns(report);
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.getErrorResults = sandbox.stub().returns([]);
             fakeCLIEngine.outputFixes = sandbox.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run --quiet .");
@@ -983,11 +1032,12 @@ describe("cli", () => {
             fakeCLIEngine.prototype = leche.fake(CLIEngine.prototype);
             sandbox.stub(fakeCLIEngine.prototype, "executeOnText").returns(report);
             sandbox.stub(fakeCLIEngine.prototype, "getFormatter").returns(() => "done");
+            sandbox.stub(fakeCLIEngine.prototype, "getRules").returns(new Map());
             fakeCLIEngine.outputFixes = sandbox.mock().never();
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix-dry-run .", "foo = bar;");
@@ -1002,7 +1052,7 @@ describe("cli", () => {
 
             localCLI = proxyquire("../../lib/cli", {
                 "./cli-engine": fakeCLIEngine,
-                "./logging": log
+                "./util/logging": log
             });
 
             const exitCode = localCLI.execute("--fix --fix-dry-run .", "foo = bar;");
