@@ -174,8 +174,8 @@ ruleTester.run("array-bracket-spacing", rule, {
         { code: "var obj = {'foo': [1, 2]}", options: ["never"] },
 
         // destructuring with type annotation
-        { code: "([ a, b ]: Array<any>) => {}", options: ["always"], parserOptions: { ecmaVersion: 6 }, parser: parser("flow-destructuring-1") },
-        { code: "([a, b]: Array< any >) => {}", options: ["never"], parserOptions: { ecmaVersion: 6 }, parser: parser("flow-destructuring-2") }
+        { code: "([ a, b ]: Array<any>) => {}", options: ["always"], parser: parser("flow-destructuring-1"), parserOptions: { ecmaVersion: 6 } },
+        { code: "([a, b]: Array< any >) => {}", options: ["never"], parser: parser("flow-destructuring-2"), parserOptions: { ecmaVersion: 6 } }
     ],
 
     invalid: [
@@ -830,6 +830,7 @@ ruleTester.run("array-bracket-spacing", rule, {
             code: "([ a, b ]: Array<any>) => {}",
             output: "([a, b]: Array<any>) => {}",
             options: ["never"],
+            parser: parser("flow-destructuring-1"),
             parserOptions: {
                 ecmaVersion: 6
             },
@@ -852,13 +853,13 @@ ruleTester.run("array-bracket-spacing", rule, {
                     line: 1,
                     column: 9
                 }
-            ],
-            parser: parser("flow-destructuring-1")
+            ]
         },
         {
             code: "([a, b]: Array< any >) => {}",
             output: "([ a, b ]: Array< any >) => {}",
             options: ["always"],
+            parser: parser("flow-destructuring-2"),
             parserOptions: {
                 ecmaVersion: 6
             },
@@ -881,8 +882,7 @@ ruleTester.run("array-bracket-spacing", rule, {
                     line: 1,
                     column: 7
                 }
-            ],
-            parser: parser("flow-destructuring-2")
+            ]
         }
     ]
 });
