@@ -207,59 +207,59 @@ ruleTester.run("func-call-spacing", rule, {
         {
             code: "f ();",
             output: "f();",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f (a, b);",
             output: "f(a, b);",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f.b ();",
             output: "f.b();",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b().c ();",
             output: "f.b().c();",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression", column: 7 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 7 }]
         },
         {
             code: "f() ()",
             output: "f()()",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "(function() {} ())",
             output: "(function() {}())",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "var f = new Foo ()",
             output: "var f = new Foo()",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "NewExpression" }]
+            errors: [{ messageId: "unexpected", type: "NewExpression" }]
         },
         {
             code: "f ( (0) )",
             output: "f( (0) )",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f(0) (1)",
             output: "f(0)(1)",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "(f) (0)",
             output: "(f)(0)",
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f ();\n t   ();",
             output: "f();\n t();",
             errors: [
-                { message: "Unexpected space between function name and paren.", type: "CallExpression" },
-                { message: "Unexpected space between function name and paren.", type: "CallExpression" }
+                { messageId: "unexpected", type: "CallExpression" },
+                { messageId: "unexpected", type: "CallExpression" }
             ]
         },
 
@@ -267,27 +267,27 @@ ruleTester.run("func-call-spacing", rule, {
         {
             code: "f\n();",
             output: null, // no change
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\r();",
             output: null, // no change
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\u2028();",
             output: null, // no change
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\u2029();",
             output: null, // no change
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\r\n();",
             output: null, // no change
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
 
         // "never"
@@ -295,69 +295,69 @@ ruleTester.run("func-call-spacing", rule, {
             code: "f ();",
             output: "f();",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f (a, b);",
             output: "f(a, b);",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f.b ();",
             output: "f.b();",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b().c ();",
             output: "f.b().c();",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression", column: 7 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 7 }]
         },
         {
             code: "f() ()",
             output: "f()()",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "(function() {} ())",
             output: "(function() {}())",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "var f = new Foo ()",
             output: "var f = new Foo()",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "NewExpression" }]
+            errors: [{ messageId: "unexpected", type: "NewExpression" }]
         },
         {
             code: "f ( (0) )",
             output: "f( (0) )",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f(0) (1)",
             output: "f(0)(1)",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "(f) (0)",
             output: "(f)(0)",
             options: ["never"],
-            errors: [{ message: "Unexpected space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f ();\n t   ();",
             output: "f();\n t();",
             options: ["never"],
             errors: [
-                { message: "Unexpected space between function name and paren.", type: "CallExpression" },
-                { message: "Unexpected space between function name and paren.", type: "CallExpression" }
+                { messageId: "unexpected", type: "CallExpression" },
+                { messageId: "unexpected", type: "CallExpression" }
             ]
         },
 
@@ -368,7 +368,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression"
                 }
             ]
@@ -383,7 +383,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression",
                     line: 2,
                     column: 23
@@ -399,7 +399,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression",
                     line: 1,
                     column: 9
@@ -415,7 +415,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression",
                     line: 1,
                     column: 9
@@ -428,7 +428,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression"
                 }
             ]
@@ -439,7 +439,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression"
                 }
             ]
@@ -450,7 +450,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression"
                 }
             ]
@@ -461,7 +461,7 @@ ruleTester.run("func-call-spacing", rule, {
             options: ["never"],
             errors: [
                 {
-                    message: "Unexpected space between function name and paren.",
+                    messageId: "unexpected",
                     type: "CallExpression"
                 }
             ]
@@ -472,133 +472,133 @@ ruleTester.run("func-call-spacing", rule, {
             code: "f();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f\n();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f(a, b);",
             output: "f (a, b);",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f\n(a, b);",
             output: "f (a, b);",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f.b();",
             output: "f.b ();",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "missing", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b\n();",
             output: "f.b ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b().c ();",
             output: "f.b ().c ();",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "missing", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b\n().c ();",
             output: "f.b ().c ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "unexpected", type: "CallExpression", column: 3 }]
         },
         {
             code: "f() ()",
             output: "f () ()",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f\n() ()",
             output: "f () ()",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\n()()",
             output: "f () ()",
             options: ["always"],
             errors: [
-                { message: "Unexpected newline between function name and paren.", type: "CallExpression" },
-                { message: "Missing space between function name and paren.", type: "CallExpression" }
+                { messageId: "unexpected", type: "CallExpression" },
+                { messageId: "missing", type: "CallExpression" }
             ]
         },
         {
             code: "(function() {}())",
             output: "(function() {} ())",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "var f = new Foo()",
             output: "var f = new Foo ()",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "NewExpression" }]
+            errors: [{ messageId: "missing", type: "NewExpression" }]
         },
         {
             code: "f( (0) )",
             output: "f ( (0) )",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f(0) (1)",
             output: "f (0) (1)",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "(f)(0)",
             output: "(f) (0)",
             options: ["always"],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f();\n t();",
             output: "f ();\n t ();",
             options: ["always"],
             errors: [
-                { message: "Missing space between function name and paren.", type: "CallExpression" },
-                { message: "Missing space between function name and paren.", type: "CallExpression" }
+                { messageId: "missing", type: "CallExpression" },
+                { messageId: "missing", type: "CallExpression" }
             ]
         },
         {
             code: "f\r();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\u2028();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\u2029();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
         {
             code: "f\r\n();",
             output: "f ();",
             options: ["always"],
-            errors: [{ message: "Unexpected newline between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "unexpected", type: "CallExpression" }]
         },
 
         // "always", "allowNewlines": true
@@ -607,69 +607,69 @@ ruleTester.run("func-call-spacing", rule, {
             output: "f ();",
             options: ["always", { allowNewlines: true }],
             errors: [
-                { message: "Missing space between function name and paren.", type: "CallExpression" }]
+                { messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f(a, b);",
             output: "f (a, b);",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f.b();",
             output: "f.b ();",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "missing", type: "CallExpression", column: 3 }]
         },
         {
             code: "f.b().c ();",
             output: "f.b ().c ();",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression", column: 3 }]
+            errors: [{ messageId: "missing", type: "CallExpression", column: 3 }]
         },
         {
             code: "f() ()",
             output: "f () ()",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "(function() {}())",
             output: "(function() {} ())",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "var f = new Foo()",
             output: "var f = new Foo ()",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "NewExpression" }]
+            errors: [{ messageId: "missing", type: "NewExpression" }]
         },
         {
             code: "f( (0) )",
             output: "f ( (0) )",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f(0) (1)",
             output: "f (0) (1)",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "(f)(0)",
             output: "(f) (0)",
             options: ["always", { allowNewlines: true }],
-            errors: [{ message: "Missing space between function name and paren.", type: "CallExpression" }]
+            errors: [{ messageId: "missing", type: "CallExpression" }]
         },
         {
             code: "f();\n t();",
             output: "f ();\n t ();",
             options: ["always", { allowNewlines: true }],
             errors: [
-                { message: "Missing space between function name and paren.", type: "CallExpression" },
-                { message: "Missing space between function name and paren.", type: "CallExpression" }
+                { messageId: "missing", type: "CallExpression" },
+                { messageId: "missing", type: "CallExpression" }
             ]
         }
     ]
