@@ -11,9 +11,6 @@
 const rule = require("../../../lib/rules/lines-around-comment"),
     RuleTester = require("../../../lib/testers/rule-tester");
 
-const afterMessage = "Expected line after comment.",
-    beforeMessage = "Expected line before comment.";
-
 //------------------------------------------------------------------------------
 // Tests
 //------------------------------------------------------------------------------
@@ -860,7 +857,7 @@ ruleTester.run("lines-around-comment", rule, {
         {
             code: "bar()\n/** block block block\n * block \n */\nvar a = 1;",
             output: "bar()\n\n/** block block block\n * block \n */\nvar a = 1;",
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
 
         // line comments
@@ -868,25 +865,25 @@ ruleTester.run("lines-around-comment", rule, {
             code: "baz()\n// A line comment with no empty line after\nvar a = 1;",
             output: "baz()\n// A line comment with no empty line after\n\nvar a = 1;",
             options: [{ afterLineComment: true }],
-            errors: [{ message: afterMessage, type: "Line" }]
+            errors: [{ messageId: "after", type: "Line" }]
         },
         {
             code: "baz()\n// A line comment with no empty line after\nvar a = 1;",
             output: "baz()\n\n// A line comment with no empty line after\nvar a = 1;",
             options: [{ beforeLineComment: true, afterLineComment: false }],
-            errors: [{ message: beforeMessage, type: "Line" }]
+            errors: [{ messageId: "before", type: "Line" }]
         },
         {
             code: "// A line comment with no empty line after\nvar a = 1;",
             output: "// A line comment with no empty line after\n\nvar a = 1;",
             options: [{ beforeLineComment: true, afterLineComment: true }],
-            errors: [{ message: afterMessage, type: "Line", line: 1, column: 1 }]
+            errors: [{ messageId: "after", type: "Line", line: 1, column: 1 }]
         },
         {
             code: "baz()\n// A line comment with no empty line after\nvar a = 1;",
             output: "baz()\n\n// A line comment with no empty line after\n\nvar a = 1;",
             options: [{ beforeLineComment: true, afterLineComment: true }],
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }, { message: afterMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }, { messageId: "after", type: "Line", line: 2 }]
         },
 
         // block comments
@@ -894,15 +891,15 @@ ruleTester.run("lines-around-comment", rule, {
             code: "bar()\n/**\n * block block block\n */\nvar a = 1;",
             output: "bar()\n\n/**\n * block block block\n */\n\nvar a = 1;",
             options: [{ afterBlockComment: true, beforeBlockComment: true }],
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }, { message: afterMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }, { messageId: "after", type: "Block", line: 2 }]
         },
         {
             code: "bar()\n/* first block comment */ /* second block comment */\nvar a = 1;",
             output: "bar()\n\n/* first block comment */ /* second block comment */\n\nvar a = 1;",
             options: [{ afterBlockComment: true, beforeBlockComment: true }],
             errors: [
-                { message: beforeMessage, type: "Block", line: 2 },
-                { message: afterMessage, type: "Block", line: 2 }
+                { messageId: "before", type: "Block", line: 2 },
+                { messageId: "after", type: "Block", line: 2 }
             ]
         },
         {
@@ -910,21 +907,21 @@ ruleTester.run("lines-around-comment", rule, {
             output: "bar()\n\n/* first block comment */ /* second block\n comment */\n\nvar a = 1;",
             options: [{ afterBlockComment: true, beforeBlockComment: true }],
             errors: [
-                { message: beforeMessage, type: "Block", line: 2 },
-                { message: afterMessage, type: "Block", line: 2 }
+                { messageId: "before", type: "Block", line: 2 },
+                { messageId: "after", type: "Block", line: 2 }
             ]
         },
         {
             code: "bar()\n/**\n * block block block\n */\nvar a = 1;",
             output: "bar()\n/**\n * block block block\n */\n\nvar a = 1;",
             options: [{ afterBlockComment: true, beforeBlockComment: false }],
-            errors: [{ message: afterMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "after", type: "Block", line: 2 }]
         },
         {
             code: "bar()\n/**\n * block block block\n */\nvar a = 1;",
             output: "bar()\n\n/**\n * block block block\n */\nvar a = 1;",
             options: [{ afterBlockComment: false, beforeBlockComment: true }],
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
         {
             code: "var a,\n// line\nb;",
@@ -933,7 +930,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true,
                 allowBlockStart: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code: "function foo(){\nvar a = 1;\n// line at block start\nvar g = 1;\n}",
@@ -942,7 +939,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true,
                 allowBlockStart: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "before", type: "Line", line: 3 }]
         },
         {
             code: "var a,\n// line\nb;",
@@ -951,7 +948,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true,
                 allowBlockEnd: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "after", type: "Line", line: 2 }]
         },
         {
             code: "function foo(){\nvar a = 1;\n\n// line at block start\nvar g = 1;\n}",
@@ -960,7 +957,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true,
                 allowBlockEnd: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 4 }]
+            errors: [{ messageId: "after", type: "Line", line: 4 }]
         },
         {
             code: "switch ('foo'){\ncase 'foo':\n// line at switch case start\nbreak;\n}",
@@ -968,7 +965,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "before", type: "Line", line: 3 }]
         },
         {
             code: "switch ('foo'){\ncase 'foo':\nbreak;\n\ndefault:\n// line at switch case start\nbreak;\n}",
@@ -976,7 +973,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 6 }]
+            errors: [{ messageId: "before", type: "Line", line: 6 }]
         },
         {
             code: "while(true){\n// line at block start and end\n}",
@@ -985,7 +982,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true,
                 allowBlockStart: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "after", type: "Line", line: 2 }]
         },
         {
             code: "while(true){\n// line at block start and end\n}",
@@ -994,7 +991,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true,
                 allowBlockEnd: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code: "class A {\n// line at class start\nconstructor() {}\n}",
@@ -1003,7 +1000,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code: "class A {\n// line at class start\nconstructor() {}\n}",
@@ -1014,7 +1011,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code: "class B {\nconstructor() {}\n\n// line at class end\n}",
@@ -1023,7 +1020,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Line", line: 4 }]
+            errors: [{ messageId: "after", type: "Line", line: 4 }]
         },
         {
             code: "class B {\nconstructor() {}\n\n// line at class end\n}",
@@ -1034,7 +1031,7 @@ ruleTester.run("lines-around-comment", rule, {
                 allowClassEnd: false
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Line", line: 4 }]
+            errors: [{ messageId: "after", type: "Line", line: 4 }]
         },
         {
             code: "switch ('foo'){\ncase 'foo':\nvar g = 1;\n\n// line at switch case end\n}",
@@ -1042,7 +1039,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterLineComment: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 5 }]
+            errors: [{ messageId: "after", type: "Line", line: 5 }]
         },
         {
             code: "switch ('foo'){\ncase 'foo':\nbreak;\n\ndefault:\nvar g = 1;\n\n// line at switch case end\n}",
@@ -1050,7 +1047,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterLineComment: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 8 }]
+            errors: [{ messageId: "after", type: "Line", line: 8 }]
         },
 
         // object start comments
@@ -1069,7 +1066,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code:
@@ -1092,7 +1089,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "before", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1109,7 +1106,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeBlockComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
         {
             code:
@@ -1136,7 +1133,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Block", line: 3 }]
+            errors: [{ messageId: "before", type: "Block", line: 3 }]
         },
         {
             code:
@@ -1154,7 +1151,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code:
@@ -1172,7 +1169,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code:
@@ -1190,7 +1187,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
         {
             code:
@@ -1208,7 +1205,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
 
         // object end comments
@@ -1227,7 +1224,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterLineComment: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "after", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1250,7 +1247,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterLineComment: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 5 }]
+            errors: [{ messageId: "after", type: "Line", line: 5 }]
         },
         {
             code:
@@ -1269,7 +1266,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterBlockComment: true
             }],
-            errors: [{ message: afterMessage, type: "Block", line: 4 }]
+            errors: [{ messageId: "after", type: "Block", line: 4 }]
         },
         {
             code:
@@ -1298,7 +1295,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterBlockComment: true
             }],
-            errors: [{ message: afterMessage, type: "Block", line: 6 }]
+            errors: [{ messageId: "after", type: "Block", line: 6 }]
         },
         {
             code:
@@ -1316,7 +1313,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "after", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1334,7 +1331,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "after", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1354,7 +1351,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Block", line: 4 }]
+            errors: [{ messageId: "after", type: "Block", line: 4 }]
         },
         {
             code:
@@ -1374,7 +1371,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Block", line: 4 }]
+            errors: [{ messageId: "after", type: "Block", line: 4 }]
         },
 
         // array start comments
@@ -1393,7 +1390,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeLineComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code:
@@ -1410,7 +1407,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 beforeBlockComment: true
             }],
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
         {
             code:
@@ -1428,7 +1425,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Line", line: 2 }]
+            errors: [{ messageId: "before", type: "Line", line: 2 }]
         },
         {
             code:
@@ -1446,7 +1443,7 @@ ruleTester.run("lines-around-comment", rule, {
                 beforeBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: beforeMessage, type: "Block", line: 2 }]
+            errors: [{ messageId: "before", type: "Block", line: 2 }]
         },
 
         // array end comments
@@ -1465,7 +1462,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterLineComment: true
             }],
-            errors: [{ message: afterMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "after", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1484,7 +1481,7 @@ ruleTester.run("lines-around-comment", rule, {
             options: [{
                 afterBlockComment: true
             }],
-            errors: [{ message: afterMessage, type: "Block", line: 4 }]
+            errors: [{ messageId: "after", type: "Block", line: 4 }]
         },
         {
             code:
@@ -1502,7 +1499,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterLineComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Line", line: 3 }]
+            errors: [{ messageId: "after", type: "Line", line: 3 }]
         },
         {
             code:
@@ -1522,7 +1519,7 @@ ruleTester.run("lines-around-comment", rule, {
                 afterBlockComment: true
             }],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: afterMessage, type: "Block", line: 4 }]
+            errors: [{ messageId: "after", type: "Block", line: 4 }]
         },
 
         // ignorePattern
@@ -1549,69 +1546,69 @@ ruleTester.run("lines-around-comment", rule, {
                 applyDefaultIgnorePatterns: false
             }],
             errors: [
-                { message: beforeMessage, type: "Block", line: 7 },
-                { message: afterMessage, type: "Block", line: 7 }
+                { messageId: "before", type: "Block", line: 7 },
+                { messageId: "after", type: "Block", line: 7 }
             ]
         },
         {
             code: "foo;\n/* eslint */",
             output: "foo;\n\n/* eslint */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* jshint */",
             output: "foo;\n\n/* jshint */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* jslint */",
             output: "foo;\n\n/* jslint */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* istanbul */",
             output: "foo;\n\n/* istanbul */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* global */",
             output: "foo;\n\n/* global */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* globals */",
             output: "foo;\n\n/* globals */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* exported */",
             output: "foo;\n\n/* exported */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo;\n/* jscs */",
             output: "foo;\n\n/* jscs */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo\n/* something else */",
             output: "foo\n\n/* something else */",
             options: [{ ignorePattern: "pragma" }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
         {
             code: "foo\n/* eslint */",
             output: "foo\n\n/* eslint */",
             options: [{ applyDefaultIgnorePatterns: false }],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         },
 
         // "fallthrough" patterns are not ignored by default
@@ -1619,7 +1616,7 @@ ruleTester.run("lines-around-comment", rule, {
             code: "foo;\n/* fallthrough */",
             output: "foo;\n\n/* fallthrough */",
             options: [],
-            errors: [{ message: beforeMessage, type: "Block" }]
+            errors: [{ messageId: "before", type: "Block" }]
         }
     ]
 
