@@ -186,7 +186,8 @@ ruleTester.run("max-len", rule, {
             code: "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tvar i = 1;",
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 80.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 80 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -198,7 +199,8 @@ ruleTester.run("max-len", rule, {
             options: [10, 4],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 10.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 10 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -210,7 +212,8 @@ ruleTester.run("max-len", rule, {
             options: [15, 4],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 15.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 15 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -222,13 +225,15 @@ ruleTester.run("max-len", rule, {
             options: [15, 4],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 15.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 15 },
                     type: "Program",
                     line: 1,
                     column: 1
                 },
                 {
-                    message: "Line 2 exceeds the maximum line length of 15.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 15 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -240,7 +245,8 @@ ruleTester.run("max-len", rule, {
             options: [20, 4, { ignoreComments: true }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 20.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -254,7 +260,8 @@ ruleTester.run("max-len", rule, {
             options: [20, 4, { ignorePattern: "fizzbuzz" }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 20.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -266,7 +273,8 @@ ruleTester.run("max-len", rule, {
             options: [10, 4, { ignoreComments: true }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 10.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 10 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -278,7 +286,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4], // ignoreComments is disabled
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 40.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -290,7 +299,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4], // ignoreUrls is disabled
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 40.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -301,7 +311,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4], // ignorePattern is disabled
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 40.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -312,7 +323,8 @@ ruleTester.run("max-len", rule, {
             options: [80, 4, { comments: 20 }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum comment line length of 20.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 1, maxCommentLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -323,7 +335,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { comments: 80 }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum comment line length of 80.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 1, maxCommentLength: 80 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -334,7 +347,8 @@ ruleTester.run("max-len", rule, {
             options: [{ code: 20 }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 20.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 20 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -345,7 +359,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { ignoreTrailingComments: true }],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 40.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 40 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -361,7 +376,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { comments: 28 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum comment line length of 28.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 2, maxCommentLength: 28 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -374,7 +390,8 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { comments: 32 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum comment line length of 32.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 2, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -388,13 +405,15 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { comments: 28 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum comment line length of 28.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 2, maxCommentLength: 28 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
-                    message: "Line 3 exceeds the maximum comment line length of 28.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 3, maxCommentLength: 28 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -408,13 +427,15 @@ ruleTester.run("max-len", rule, {
             options: [40, 4, { comments: 32 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum comment line length of 32.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 2, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
-                    message: "Line 3 exceeds the maximum comment line length of 32.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 3, maxCommentLength: 32 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -428,13 +449,15 @@ ruleTester.run("max-len", rule, {
             options: [39, 4, { comments: 35 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 39.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 39 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
-                    message: "Line 3 exceeds the maximum comment line length of 35.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 3, maxCommentLength: 35 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -448,13 +471,15 @@ ruleTester.run("max-len", rule, {
             options: [42, 4, { comments: 32 }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum comment line length of 32.",
+                    messageId: "maxComment",
+                    data: { lineNumber: 2, maxCommentLength: 32 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
-                    message: "Line 3 exceeds the maximum line length of 42.",
+                    messageId: "max",
+                    data: { lineNumber: 3, maxLength: 42 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -469,7 +494,8 @@ ruleTester.run("max-len", rule, {
             options: [20, { ignoreComments: true }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 20.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 20 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -483,7 +509,8 @@ ruleTester.run("max-len", rule, {
             options: [29, { ignoreStrings: false, ignoreTemplateLiterals: true }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -495,7 +522,8 @@ ruleTester.run("max-len", rule, {
             options: [29, { ignoreStrings: false, ignoreRegExpLiterals: false }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -507,7 +535,8 @@ ruleTester.run("max-len", rule, {
             options: [29, { ignoreStrings: false, ignoreRegExpLiterals: true }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -519,7 +548,8 @@ ruleTester.run("max-len", rule, {
             options: [29, { ignoreStrings: false, ignoreTemplateLiterals: true }],
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -532,7 +562,8 @@ ruleTester.run("max-len", rule, {
             parserOptions,
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
@@ -545,13 +576,15 @@ ruleTester.run("max-len", rule, {
             parserOptions,
             errors: [
                 {
-                    message: "Line 2 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 2, maxLength: 29 },
                     type: "Program",
                     line: 2,
                     column: 1
                 },
                 {
-                    message: "Line 3 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 3, maxLength: 29 },
                     type: "Program",
                     line: 3,
                     column: 1
@@ -564,7 +597,8 @@ ruleTester.run("max-len", rule, {
             parserOptions: { ecmaFeatures: { jsx: true } },
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 29.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 29 },
                     type: "Program",
                     line: 1,
                     column: 1
@@ -578,7 +612,8 @@ ruleTester.run("max-len", rule, {
             options: [10],
             errors: [
                 {
-                    message: "Line 1 exceeds the maximum line length of 10.",
+                    messageId: "max",
+                    data: { lineNumber: 1, maxLength: 10 },
                     type: "Program",
                     line: 1,
                     column: 1
