@@ -271,6 +271,21 @@ ruleTester.run("no-unused-vars", rule, {
             code: "(({a, ...rest}) => rest)",
             options: [{ args: "all", ignoreRestSiblings: true }],
             parserOptions: { ecmaVersion: 2018 }
+        },
+
+        // https://github.com/eslint/eslint/issues/10952
+        "/*eslint use-every-a:1*/ !function(b, a) { return 1 }",
+
+        // https://github.com/eslint/eslint/issues/10982
+        "var a = function () { a(); }; a();",
+        "var a = function(){ return function () { a(); } }; a();",
+        {
+            code: "const a = () => { a(); }; a();",
+            parserOptions: { ecmaVersion: 2015 }
+        },
+        {
+            code: "const a = () => () => { a(); }; a();",
+            parserOptions: { ecmaVersion: 2015 }
         }
     ],
     invalid: [
@@ -462,10 +477,10 @@ ruleTester.run("no-unused-vars", rule, {
         // surrogate pair.
         {
             code: "/*global 𠮷𩸽, 𠮷*/\n\\u{20BB7}\\u{29E3D};",
+            env: { es6: true },
             errors: [
                 { line: 1, column: 16, message: "'𠮷' is defined but never used." }
-            ],
-            env: { es6: true }
+            ]
         },
 
         // https://github.com/eslint/eslint/issues/4047
@@ -713,6 +728,28 @@ ruleTester.run("no-unused-vars", rule, {
             code: "(function(_a) {})();",
             options: [{ args: "all", caughtErrorsIgnorePattern: "^_" }],
             errors: [{ message: "'_a' is defined but never used." }]
+        },
+
+        // https://github.com/eslint/eslint/issues/10982
+        {
+            code: "var a = function() { a(); };",
+            errors: [{ message: "'a' is assigned a value but never used." }]
+        },
+        {
+            code: "var a = function(){ return function() { a(); } };",
+            errors: [
+                { message: "'a' is assigned a value but never used." }
+            ]
+        },
+        {
+            code: "const a = () => { a(); };",
+            parserOptions: { ecmaVersion: 2015 },
+            errors: [{ message: "'a' is assigned a value but never used." }]
+        },
+        {
+            code: "const a = () => () => { a(); };",
+            parserOptions: { ecmaVersion: 2015 },
+            errors: [{ message: "'a' is assigned a value but never used." }]
         }
     ]
 });
