@@ -515,6 +515,7 @@ ruleTester.run("object-curly-newline", rule, {
         // "ExportDeclaration" ---------------------------------------------
         {
             code: [
+                "var a = 0, b = 0;",
                 "export {a,",
                 "b};"
             ].join("\n"),
@@ -522,6 +523,7 @@ ruleTester.run("object-curly-newline", rule, {
         },
         {
             code: [
+                "var a = 0, b = 0;",
                 "export {",
                 "a as a, b",
                 "} from 'module';"
@@ -668,11 +670,11 @@ ruleTester.run("object-curly-newline", rule, {
                 "} : MyType) {}"
             ].join("\n"),
             options: ["always"],
+            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-singleline"),
             errors: [
                 { line: 1, column: 14, message: "Expected a line break after this opening brace." },
                 { line: 1, column: 21, message: "Expected a line break before this closing brace." }
-            ],
-            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-singleline")
+            ]
         },
         {
             code: "function foo({ a, b } : { a : string, b : string }) {}",
@@ -682,11 +684,11 @@ ruleTester.run("object-curly-newline", rule, {
                 "} : { a : string, b : string }) {}"
             ].join("\n"),
             options: ["always"],
+            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-singleline-type-literal"),
             errors: [
                 { line: 1, column: 14, message: "Expected a line break after this opening brace." },
                 { line: 1, column: 21, message: "Expected a line break before this closing brace." }
-            ],
-            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-singleline-type-literal")
+            ]
         },
 
         // "never" ------------------------------------------------------------
@@ -782,11 +784,11 @@ ruleTester.run("object-curly-newline", rule, {
                 " b} : MyType) {}"
             ].join("\n"),
             options: ["never"],
+            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-multiline"),
             errors: [
                 { line: 1, column: 14, message: "Unexpected line break after this opening brace." },
                 { line: 4, column: 1, message: "Unexpected line break before this closing brace." }
-            ],
-            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-multiline")
+            ]
         },
         {
             code: [
@@ -800,11 +802,11 @@ ruleTester.run("object-curly-newline", rule, {
                 " b} : { a : string, b : string }) {}"
             ].join("\n"),
             options: ["never"],
+            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-multiline-type-literal"),
             errors: [
                 { line: 1, column: 14, message: "Unexpected line break after this opening brace." },
                 { line: 4, column: 1, message: "Unexpected line break before this closing brace." }
-            ],
-            parser: resolvePath(__dirname, "../../fixtures/parsers/object-curly-newline/flow-stub-parser-multiline-type-literal")
+            ]
         },
 
         // "multiline" ---------------------------------------------------------
@@ -1637,19 +1639,21 @@ ruleTester.run("object-curly-newline", rule, {
         // "ExportDeclaration" ---------------------------------------------
         {
             code: [
+                "var a = 0; var b = 0;",
                 "export {",
                 "    a,",
                 "    b",
                 "};"
             ].join("\n"),
             output: [
+                "var a = 0; var b = 0;",
                 "export {a,",
                 "    b};"
             ].join("\n"),
             options: [{ ExportDeclaration: "never" }],
             errors: [
-                { line: 1, column: 8, message: "Unexpected line break after this opening brace." },
-                { line: 4, column: 1, message: "Unexpected line break before this closing brace." }
+                { line: 2, column: 8, message: "Unexpected line break after this opening brace." },
+                { line: 5, column: 1, message: "Unexpected line break before this closing brace." }
             ]
         },
         {
