@@ -259,7 +259,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "delete (foo.bar)",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'delete' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "delete" },
                 type: "UnaryExpression"
             }]
         },
@@ -268,7 +269,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "delete (foo[\"bar\"]);",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'delete' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "delete" },
                 type: "UnaryExpression"
             }]
         },
@@ -277,7 +279,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "delete(foo.bar)",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'delete'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "delete" },
                 type: "UnaryExpression"
             }]
         },
@@ -286,7 +289,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new (Foo)",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'new' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "new" },
                 type: "NewExpression"
             }]
         },
@@ -295,7 +299,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new(Foo)",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'new'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "new" },
                 type: "NewExpression"
             }]
         },
@@ -304,7 +309,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new (Foo())",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'new' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "new" },
                 type: "NewExpression"
             }]
         },
@@ -313,7 +319,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new[foo][0]",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'new'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "new" },
                 type: "NewExpression"
             }]
         },
@@ -323,7 +330,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof (foo)",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'typeof' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -332,7 +340,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof(foo)",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'typeof'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -341,7 +350,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof [foo]",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'typeof' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -350,7 +360,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof[foo]",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'typeof'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -359,7 +370,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof {foo:true}",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'typeof' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -368,7 +380,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof{foo:true}",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'typeof'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -377,7 +390,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "typeof !foo",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'typeof' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "typeof" },
                 type: "UnaryExpression"
             }]
         },
@@ -387,7 +401,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void (0);",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'void' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -396,7 +411,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void (foo);",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'void' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -405,7 +421,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void [foo];",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'void' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -414,7 +431,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void {a:0};",
             options: [{ words: true }],
             errors: [{
-                message: "Unary word operator 'void' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -423,7 +441,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void(foo)",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'void'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -432,7 +451,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "void[foo]",
             options: [{ words: false }],
             errors: [{
-                message: "Unexpected space after unary word operator 'void'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "void" },
                 type: "UnaryExpression"
             }]
         },
@@ -442,7 +462,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "!foo",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '!'."
+                messageId: "unexpectedAfter",
+                data: { operator: "!" }
             }]
         },
         {
@@ -450,7 +471,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "! foo",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Unary operator '!' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "!" }
             }]
         },
 
@@ -459,7 +481,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "!!foo",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '!'.",
+                messageId: "unexpectedAfter",
+                data: { operator: "!" },
                 type: "UnaryExpression",
                 line: 1,
                 column: 2
@@ -470,7 +493,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "!! foo",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Unary operator '!' must be followed by whitespace.",
+                messageId: "operator",
+                data: { operator: "!" },
                 type: "UnaryExpression",
                 line: 1,
                 column: 2
@@ -482,7 +506,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "-1",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '-'.",
+                messageId: "unexpectedAfter",
+                data: { operator: "-" },
                 type: "UnaryExpression"
             }]
         },
@@ -491,7 +516,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "- 1",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Unary operator '-' must be followed by whitespace.",
+                messageId: "operator",
+                data: { operator: "-" },
                 type: "UnaryExpression"
             }]
         },
@@ -501,7 +527,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "foo ++",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Space is required before unary expressions '++'."
+                messageId: "beforeUnaryExpressions",
+                data: { token: "++" }
             }]
         },
         {
@@ -509,7 +536,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "foo++",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space before unary operator '++'."
+                messageId: "unexpectedBefore",
+                data: { operator: "++" }
             }]
         },
         {
@@ -517,7 +545,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "++foo",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '++'."
+                messageId: "unexpectedAfter",
+                data: { operator: "++" }
             }]
         },
         {
@@ -525,7 +554,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "++ foo",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Unary operator '++' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "++" }
             }]
         },
         {
@@ -533,14 +563,16 @@ ruleTester.run("space-unary-ops", rule, {
             output: "foo .bar ++",
             options: [{ nonwords: true }],
             errors: [{
-                message: "Space is required before unary expressions '++'."
+                messageId: "beforeUnaryExpressions",
+                data: { token: "++" }
             }]
         },
         {
             code: "foo.bar --",
             output: "foo.bar--",
             errors: [{
-                message: "Unexpected space before unary operator '--'."
+                messageId: "unexpectedBefore",
+                data: { operator: "--" }
             }]
         },
         {
@@ -548,7 +580,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: null,
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '+'."
+                messageId: "unexpectedAfter",
+                data: { operator: "+" }
             }]
         },
         {
@@ -556,7 +589,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: null,
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '+'."
+                messageId: "unexpectedAfter",
+                data: { operator: "+" }
             }]
         },
         {
@@ -564,7 +598,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: null,
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '-'."
+                messageId: "unexpectedAfter",
+                data: { operator: "-" }
             }]
         },
         {
@@ -572,7 +607,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: null,
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '-'."
+                messageId: "unexpectedAfter",
+                data: { operator: "-" }
             }]
         },
         {
@@ -580,7 +616,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "+-foo",
             options: [{ nonwords: false }],
             errors: [{
-                message: "Unexpected space after unary operator '+'."
+                messageId: "unexpectedAfter",
+                data: { operator: "+" }
             }]
         },
         {
@@ -588,7 +625,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "function *foo() { yield (0) }",
             parserOptions: { ecmaVersion: 6 },
             errors: [{
-                message: "Unary word operator 'yield' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "yield" },
                 type: "YieldExpression",
                 line: 1,
                 column: 19
@@ -600,7 +638,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: false }],
             parserOptions: { ecmaVersion: 6 },
             errors: [{
-                message: "Unexpected space after unary word operator 'yield'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "yield" },
                 type: "YieldExpression",
                 line: 1,
                 column: 19
@@ -611,7 +650,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "function *foo() { yield +0 }",
             parserOptions: { ecmaVersion: 6 },
             errors: [{
-                message: "Unary word operator 'yield' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "yield" },
                 type: "YieldExpression",
                 line: 1,
                 column: 19
@@ -622,7 +662,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "foo ++",
             options: [{ nonwords: true, overrides: { "++": true } }],
             errors: [{
-                message: "Space is required before unary expressions '++'."
+                messageId: "beforeUnaryExpressions",
+                data: { token: "++" }
             }]
         },
         {
@@ -630,7 +671,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "foo ++",
             options: [{ nonwords: false, overrides: { "++": true } }],
             errors: [{
-                message: "Space is required before unary expressions '++'."
+                messageId: "beforeUnaryExpressions",
+                data: { token: "++" }
             }]
         },
         {
@@ -638,7 +680,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "++ foo",
             options: [{ nonwords: true, overrides: { "++": true } }],
             errors: [{
-                message: "Unary operator '++' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "++" }
             }]
         },
         {
@@ -646,7 +689,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "++ foo",
             options: [{ nonwords: false, overrides: { "++": true } }],
             errors: [{
-                message: "Unary operator '++' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "++" }
             }]
         },
         {
@@ -654,7 +698,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "! foo",
             options: [{ nonwords: true, overrides: { "!": true } }],
             errors: [{
-                message: "Unary operator '!' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "!" }
             }]
         },
         {
@@ -662,7 +707,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "! foo",
             options: [{ nonwords: false, overrides: { "!": true } }],
             errors: [{
-                message: "Unary operator '!' must be followed by whitespace."
+                messageId: "operator",
+                data: { operator: "!" }
             }]
         },
         {
@@ -670,7 +716,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new (Foo)",
             options: [{ words: true, overrides: { new: true } }],
             errors: [{
-                message: "Unary word operator 'new' must be followed by whitespace."
+                messageId: "wordOperator",
+                data: { word: "new" }
             }]
         },
         {
@@ -678,7 +725,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "new (Foo)",
             options: [{ words: false, overrides: { new: true } }],
             errors: [{
-                message: "Unary word operator 'new' must be followed by whitespace."
+                messageId: "wordOperator",
+                data: { word: "new" }
             }]
         },
         {
@@ -687,7 +735,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: true, overrides: { yield: true } }],
             parserOptions: { ecmaVersion: 6 },
             errors: [{
-                message: "Unary word operator 'yield' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "yield" },
                 type: "YieldExpression",
                 line: 1,
                 column: 19
@@ -699,7 +748,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: false, overrides: { yield: true } }],
             parserOptions: { ecmaVersion: 6 },
             errors: [{
-                message: "Unary word operator 'yield' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "yield" },
                 type: "YieldExpression",
                 line: 1,
                 column: 19
@@ -710,7 +760,8 @@ ruleTester.run("space-unary-ops", rule, {
             output: "async function foo() { await {foo: 'bar'} }",
             parserOptions: { ecmaVersion: 8 },
             errors: [{
-                message: "Unary word operator 'await' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "await" },
                 type: "AwaitExpression",
                 line: 1,
                 column: 24
@@ -722,7 +773,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: false, overrides: { await: true } }],
             parserOptions: { ecmaVersion: 8 },
             errors: [{
-                message: "Unary word operator 'await' must be followed by whitespace.",
+                messageId: "wordOperator",
+                data: { word: "await" },
                 type: "AwaitExpression",
                 line: 1,
                 column: 24
@@ -734,7 +786,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: false }],
             parserOptions: { ecmaVersion: 8 },
             errors: [{
-                message: "Unexpected space after unary word operator 'await'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "await" },
                 type: "AwaitExpression",
                 line: 1,
                 column: 24
@@ -746,7 +799,8 @@ ruleTester.run("space-unary-ops", rule, {
             options: [{ words: true, overrides: { await: false } }],
             parserOptions: { ecmaVersion: 8 },
             errors: [{
-                message: "Unexpected space after unary word operator 'await'.",
+                messageId: "unexpectedAfterWord",
+                data: { word: "await" },
                 type: "AwaitExpression",
                 line: 1,
                 column: 24
