@@ -95,36 +95,36 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["never"],
             errors: [
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" }
+                { messageId: "never", type: "ExpressionStatement" }
             ]
         }, {
             code: "function foo() { 'use strict'; return; }",
             output: null,
             options: ["never"],
             errors: [
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" }
+                { messageId: "never", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = function() { 'use strict'; return; };",
             output: null,
             options: ["never"],
             errors: [
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" }
+                { messageId: "never", type: "ExpressionStatement" }
             ]
         }, {
             code: "function foo() { return function() { 'use strict'; return; }; }",
             output: null,
             options: ["never"],
             errors: [
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" }
+                { messageId: "never", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { \"use strict\"; return; }",
             output: null,
             options: ["never"],
             errors: [
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" },
-                { message: "Strict mode is not permitted.", type: "ExpressionStatement" }
+                { messageId: "never", type: "ExpressionStatement" },
+                { messageId: "never", type: "ExpressionStatement" }
             ]
         }, {
             code: "\"use strict\"; foo();",
@@ -132,7 +132,7 @@ ruleTester.run("strict", rule, {
             options: ["never"],
             parserOptions: { sourceType: "module" },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -140,8 +140,8 @@ ruleTester.run("strict", rule, {
             options: ["never"],
             parserOptions: { ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" }
+                { messageId: "implied", type: "ExpressionStatement" },
+                { messageId: "implied", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -149,8 +149,8 @@ ruleTester.run("strict", rule, {
             options: ["never"],
             parserOptions: { sourceType: "module", ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" },
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         },
 
@@ -160,23 +160,23 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["global"],
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" }
+                { messageId: "global", type: "Program" }
             ]
         }, {
             code: "function foo() { 'use strict'; return; }",
             output: null,
             options: ["global"],
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" },
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "Program" },
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = function() { 'use strict'; return; }",
             output: null,
             options: ["global"],
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" },
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "Program" },
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = () => { 'use strict'; return () => 1; }",
@@ -184,29 +184,29 @@ ruleTester.run("strict", rule, {
             options: ["global"],
             parserOptions: { ecmaVersion: 6 },
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" },
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "Program" },
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
             output: null,
             options: ["global"],
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; var foo = function() { 'use strict'; return; };",
             output: null,
             options: ["global"],
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; 'use strict'; foo();",
             output: "'use strict';  foo();",
             options: ["global"],
             errors: [
-                { message: "Multiple 'use strict' directives.", type: "ExpressionStatement" }
+                { messageId: "multiple", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; foo();",
@@ -214,7 +214,7 @@ ruleTester.run("strict", rule, {
             options: ["global"],
             parserOptions: { sourceType: "module" },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -222,8 +222,8 @@ ruleTester.run("strict", rule, {
             options: ["global"],
             parserOptions: { ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" }
+                { messageId: "implied", type: "ExpressionStatement" },
+                { messageId: "implied", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -231,8 +231,8 @@ ruleTester.run("strict", rule, {
             options: ["global"],
             parserOptions: { sourceType: "module", ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" },
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         },
 
@@ -242,28 +242,28 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "function", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; (function() { 'use strict'; return true; }());",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "function", type: "ExpressionStatement" }
             ]
         }, {
             code: "(function() { 'use strict'; function f() { 'use strict'; return } return true; }());",
             output: "(function() { 'use strict'; function f() {  return } return true; }());",
             options: ["function"],
             errors: [
-                { message: "Unnecessary 'use strict' directive.", type: "ExpressionStatement" }
+                { messageId: "unnecessary", type: "ExpressionStatement" }
             ]
         }, {
             code: "(function() { return true; }());",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionExpression" }
+                { messageId: "function", type: "FunctionExpression" }
             ]
         }, {
             code: "(() => { return true; })();",
@@ -271,7 +271,7 @@ ruleTester.run("strict", rule, {
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ArrowFunctionExpression" }
+                { messageId: "function", type: "ArrowFunctionExpression" }
             ]
         }, {
             code: "(() => true)();",
@@ -279,29 +279,29 @@ ruleTester.run("strict", rule, {
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ArrowFunctionExpression" }
+                { messageId: "function", type: "ArrowFunctionExpression" }
             ]
         }, {
             code: "var foo = function() { foo(); 'use strict'; return; }; function bar() { foo(); 'use strict'; }",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionExpression" },
-                { message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }
+                { messageId: "function", type: "FunctionExpression" },
+                { messageId: "function", type: "FunctionDeclaration" }
             ]
         }, {
             code: "function foo() { 'use strict'; 'use strict'; return; }",
             output: "function foo() { 'use strict';  return; }",
             options: ["function"],
             errors: [
-                { message: "Multiple 'use strict' directives.", type: "ExpressionStatement" }
+                { messageId: "multiple", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = function() { 'use strict'; 'use strict'; return; }",
             output: "var foo = function() { 'use strict';  return; }",
             options: ["function"],
             errors: [
-                { message: "Multiple 'use strict' directives.", type: "ExpressionStatement" }
+                { messageId: "multiple", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = function() {  'use strict'; return; }",
@@ -309,7 +309,7 @@ ruleTester.run("strict", rule, {
             options: ["function"],
             parserOptions: { sourceType: "module" },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -317,8 +317,8 @@ ruleTester.run("strict", rule, {
             options: ["function"],
             parserOptions: { ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" }
+                { messageId: "implied", type: "ExpressionStatement" },
+                { messageId: "implied", type: "ExpressionStatement" }
             ]
         }, {
             code: "'use strict'; function foo() { 'use strict'; return; }",
@@ -326,52 +326,52 @@ ruleTester.run("strict", rule, {
             options: ["function"],
             parserOptions: { sourceType: "module", ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" },
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         }, {
             code: "function foo() { return function() { 'use strict'; return; }; }",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }
+                { messageId: "function", type: "FunctionDeclaration" }
             ]
         }, {
             code: "var foo = function() { function bar() { 'use strict'; return; } return; }",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionExpression" }
+                { messageId: "function", type: "FunctionExpression" }
             ]
         }, {
             code: "function foo() { 'use strict'; return; } var bar = function() { return; };",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionExpression" }
+                { messageId: "function", type: "FunctionExpression" }
             ]
         }, {
             code: "var foo = function() { 'use strict'; return; }; function bar() { return; };",
             output: null,
             options: ["function"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }
+                { messageId: "function", type: "FunctionDeclaration" }
             ]
         }, {
             code: "function foo() { 'use strict'; return function() { 'use strict'; 'use strict'; return; }; }",
             output: "function foo() { 'use strict'; return function() {   return; }; }",
             options: ["function"],
             errors: [
-                { message: "Unnecessary 'use strict' directive.", type: "ExpressionStatement" },
-                { message: "Multiple 'use strict' directives.", type: "ExpressionStatement" }
+                { messageId: "unnecessary", type: "ExpressionStatement" },
+                { messageId: "multiple", type: "ExpressionStatement" }
             ]
         }, {
             code: "var foo = function() { 'use strict'; function bar() { 'use strict'; 'use strict'; return; } }",
             output: "var foo = function() { 'use strict'; function bar() {   return; } }",
             options: ["function"],
             errors: [
-                { message: "Unnecessary 'use strict' directive.", type: "ExpressionStatement" },
-                { message: "Multiple 'use strict' directives.", type: "ExpressionStatement" }
+                { messageId: "unnecessary", type: "ExpressionStatement" },
+                { messageId: "multiple", type: "ExpressionStatement" }
             ]
         },
         {
@@ -379,7 +379,7 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: "Use the function form of 'use strict'.", type: "ArrowFunctionExpression" }]
+            errors: [{ messageId: "function", type: "ArrowFunctionExpression" }]
         },
 
         // Classes
@@ -388,21 +388,21 @@ ruleTester.run("strict", rule, {
             output: "class A { constructor() {  } }",
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: "'use strict' is unnecessary inside of classes.", type: "ExpressionStatement" }]
+            errors: [{ messageId: "unnecessaryInClasses", type: "ExpressionStatement" }]
         },
         {
             code: "class A { foo() { \"use strict\"; } }",
             output: "class A { foo() {  } }",
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: "'use strict' is unnecessary inside of classes.", type: "ExpressionStatement" }]
+            errors: [{ messageId: "unnecessaryInClasses", type: "ExpressionStatement" }]
         },
         {
             code: "class A { foo() { function bar() { \"use strict\"; } } }",
             output: "class A { foo() { function bar() {  } } }",
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: [{ message: "'use strict' is unnecessary inside of classes.", type: "ExpressionStatement" }]
+            errors: [{ messageId: "unnecessaryInClasses", type: "ExpressionStatement" }]
         },
 
 
@@ -412,8 +412,8 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["safe"],
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ExpressionStatement" },
-                { message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }
+                { messageId: "function", type: "ExpressionStatement" },
+                { messageId: "function", type: "FunctionDeclaration" }
             ]
         },
         {
@@ -422,8 +422,8 @@ ruleTester.run("strict", rule, {
             options: ["safe"],
             parserOptions: { ecmaFeatures: { globalReturn: true } },
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" },
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "Program" },
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         },
         {
@@ -432,8 +432,8 @@ ruleTester.run("strict", rule, {
             options: ["safe"],
             parserOptions: { ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" }
+                { messageId: "implied", type: "ExpressionStatement" },
+                { messageId: "implied", type: "ExpressionStatement" }
             ]
         },
         {
@@ -442,8 +442,8 @@ ruleTester.run("strict", rule, {
             options: ["safe"],
             parserOptions: { sourceType: "module", ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" },
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         },
 
@@ -452,22 +452,22 @@ ruleTester.run("strict", rule, {
             code: "'use strict'; function foo() { return; }",
             output: null,
             errors: [
-                { message: "Use the function form of 'use strict'.", type: "ExpressionStatement" },
-                { message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }
+                { messageId: "function", type: "ExpressionStatement" },
+                { messageId: "function", type: "FunctionDeclaration" }
             ]
         },
         {
             code: "function foo() { return; }",
             output: null,
-            errors: [{ message: "Use the function form of 'use strict'.", type: "FunctionDeclaration" }]
+            errors: [{ messageId: "function", type: "FunctionDeclaration" }]
         },
         {
             code: "function foo() { 'use strict'; return; }",
             output: null,
             parserOptions: { ecmaFeatures: { globalReturn: true } },
             errors: [
-                { message: "Use the global form of 'use strict'.", type: "Program" },
-                { message: "Use the global form of 'use strict'.", type: "ExpressionStatement" }
+                { messageId: "global", type: "Program" },
+                { messageId: "global", type: "ExpressionStatement" }
             ]
         },
         {
@@ -475,8 +475,8 @@ ruleTester.run("strict", rule, {
             output: " function foo() {  return; }",
             parserOptions: { ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary when implied strict mode is enabled.", type: "ExpressionStatement" }
+                { messageId: "implied", type: "ExpressionStatement" },
+                { messageId: "implied", type: "ExpressionStatement" }
             ]
         },
         {
@@ -484,8 +484,8 @@ ruleTester.run("strict", rule, {
             output: " function foo() {  return; }",
             parserOptions: { sourceType: "module", ecmaFeatures: { impliedStrict: true } },
             errors: [
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" },
-                { message: "'use strict' is unnecessary inside of modules.", type: "ExpressionStatement" }
+                { messageId: "module", type: "ExpressionStatement" },
+                { messageId: "module", type: "ExpressionStatement" }
             ]
         },
 
@@ -495,14 +495,14 @@ ruleTester.run("strict", rule, {
             output: null,
             options: [],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "(function() { 'use strict'; function foo(a = 0) { 'use strict' } }())",
             output: null,
             options: [],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "function foo(a = 0) { 'use strict' }",
@@ -511,7 +511,7 @@ ruleTester.run("strict", rule, {
             parserOptions: { ecmaVersion: 6, ecmaFeatures: { globalReturn: true } },
             errors: [
                 "Use the global form of 'use strict'.",
-                "'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."
+                { messageId: "nonSimpleParameterList" }
             ]
         },
         {
@@ -519,14 +519,14 @@ ruleTester.run("strict", rule, {
             output: null,
             options: [],
             parserOptions: { ecmaVersion: 6, ecmaFeatures: { globalReturn: true } },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "function foo(a = 0) { 'use strict' }",
             output: null,
             options: ["never"],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "function foo(a = 0) { 'use strict' }",
@@ -535,7 +535,7 @@ ruleTester.run("strict", rule, {
             parserOptions: { ecmaVersion: 6 },
             errors: [
                 "Use the global form of 'use strict'.",
-                "'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."
+                { messageId: "nonSimpleParameterList" }
             ]
         },
         {
@@ -543,28 +543,28 @@ ruleTester.run("strict", rule, {
             output: null,
             options: ["global"],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "function foo(a = 0) { 'use strict' }",
             output: null,
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "(function() { 'use strict'; function foo(a = 0) { 'use strict' } }())",
             output: null,
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016."]
+            errors: [{ messageId: "nonSimpleParameterList" }]
         },
         {
             code: "function foo(a = 0) { }",
             output: null,
             options: ["function"],
             parserOptions: { ecmaVersion: 6 },
-            errors: ["Wrap function 'foo' in a function with 'use strict' directive."]
+            errors: [{ messageId: "wrap", data: { name: "function 'foo'" } }]
         },
         {
             code: "(function() { function foo(a = 0) { } }())",
